==> qtjambi-datavisualization-6.2.9-sources.jar: io/qt/datavis/QValue3DAxisFormatter.java <==
package io.qt.datavis;


/**
 * <p>Base class for value axis formatters</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html">QValue3DAxisFormatter</a></p>
 */
public class QValue3DAxisFormatter extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QValue3DAxisFormatter.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QValue3DAxisFormatter(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QValue3DAxisFormatter() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#QValue3DAxisFormatter-1">QValue3DAxisFormatter::QValue3DAxisFormatter(QObject*)</a></p>
     */
    public QValue3DAxisFormatter(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QValue3DAxisFormatter instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#allowNegatives">QValue3DAxisFormatter::allowNegatives()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final boolean allowNegatives(){
        return allowNegatives_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean allowNegatives_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#allowZero">QValue3DAxisFormatter::allowZero()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final boolean allowZero(){
        return allowZero_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean allowZero_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#axis">QValue3DAxisFormatter::axis()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.datavis.QValue3DAxis axis(){
        return axis_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QValue3DAxis axis_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#gridPositions">QValue3DAxisFormatter::gridPositions()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.Float> gridPositions(){
        return gridPositions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Float> gridPositions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#labelPositions">QValue3DAxisFormatter::labelPositions()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.Float> labelPositions(){
        return labelPositions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Float> labelPositions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#labelStrings">QValue3DAxisFormatter::labelStrings()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.String> labelStrings(){
        return labelStrings_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.String> labelStrings_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#locale">QValue3DAxisFormatter::locale()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QLocale locale(){
        return locale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QLocale locale_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #markDirty(boolean)}
     *  with <code>labelsChange = false</code>.</p>
     */
    @io.qt.QtUninvokable
    protected final void markDirty() {
        markDirty((boolean)false);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#markDirty">QValue3DAxisFormatter::markDirty(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void markDirty(boolean labelsChange){
        markDirty_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), labelsChange);
    }
    
    @io.qt.QtUninvokable
    private native void markDirty_native_bool(long __this__nativeId, boolean labelsChange);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#setAllowNegatives">QValue3DAxisFormatter::setAllowNegatives(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setAllowNegatives(boolean allow){
        setAllowNegatives_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), allow);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowNegatives_native_bool(long __this__nativeId, boolean allow);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#setAllowZero">QValue3DAxisFormatter::setAllowZero(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setAllowZero(boolean allow){
        setAllowZero_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), allow);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowZero_native_bool(long __this__nativeId, boolean allow);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#setLocale">QValue3DAxisFormatter::setLocale(QLocale)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setLocale(io.qt.core.QLocale locale){
        setLocale_native_cref_QLocale(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(locale));
    }
    
    @io.qt.QtUninvokable
    private native void setLocale_native_cref_QLocale(long __this__nativeId, long locale);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#subGridPositions">QValue3DAxisFormatter::subGridPositions()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.Float> subGridPositions(){
        return subGridPositions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Float> subGridPositions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#createNewInstance">QValue3DAxisFormatter::createNewInstance()const</a></p>
     */
    @io.qt.QtUninvokable
    protected io.qt.datavis.QValue3DAxisFormatter createNewInstance(){
        return createNewInstance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QValue3DAxisFormatter createNewInstance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#populateCopy">QValue3DAxisFormatter::populateCopy(QValue3DAxisFormatter&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    protected void populateCopy(io.qt.datavis.QValue3DAxisFormatter copy){
        populateCopy_native_ref_QValue3DAxisFormatter_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(copy));
    }
    
    @io.qt.QtUninvokable
    private native void populateCopy_native_ref_QValue3DAxisFormatter_constfct(long __this__nativeId, long copy);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#positionAt">QValue3DAxisFormatter::positionAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float positionAt(float value){
        return positionAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native float positionAt_native_float_constfct(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#recalculate">QValue3DAxisFormatter::recalculate()</a></p>
     */
    @io.qt.QtUninvokable
    protected void recalculate(){
        recalculate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void recalculate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#stringForValue">QValue3DAxisFormatter::stringForValue(qreal,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    protected java.lang.String stringForValue(double value, java.lang.String format){
        return stringForValue_native_qreal_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), value, format);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String stringForValue_native_qreal_cref_QString_constfct(long __this__nativeId, double value, java.lang.String format);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#valueAt">QValue3DAxisFormatter::valueAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float valueAt(float position){
        return valueAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), position);
    }
    
    @io.qt.QtUninvokable
    private native float valueAt_native_float_constfct(long __this__nativeId, float position);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QValue3DAxisFormatter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QValue3DAxisFormatter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QValue3DAxisFormatter instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-datavisualization-6.3.2-sources.jar: io/qt/datavis/QValue3DAxisFormatter.java <==
package io.qt.datavis;


/**
 * <p>Base class for value axis formatters</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html">QValue3DAxisFormatter</a></p>
 */
public class QValue3DAxisFormatter extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QValue3DAxisFormatter.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QValue3DAxisFormatter(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QValue3DAxisFormatter() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#QValue3DAxisFormatter-1">QValue3DAxisFormatter::QValue3DAxisFormatter(QObject*)</a></p>
     */
    public QValue3DAxisFormatter(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QValue3DAxisFormatter instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#allowNegatives">QValue3DAxisFormatter::allowNegatives()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final boolean allowNegatives(){
        return allowNegatives_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean allowNegatives_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#allowZero">QValue3DAxisFormatter::allowZero()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final boolean allowZero(){
        return allowZero_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean allowZero_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#axis">QValue3DAxisFormatter::axis()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.datavis.QValue3DAxis axis(){
        return axis_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QValue3DAxis axis_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#gridPositions">QValue3DAxisFormatter::gridPositions()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.Float> gridPositions(){
        return gridPositions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Float> gridPositions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#labelPositions">QValue3DAxisFormatter::labelPositions()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.Float> labelPositions(){
        return labelPositions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Float> labelPositions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#labelStrings">QValue3DAxisFormatter::labelStrings()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.String> labelStrings(){
        return labelStrings_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.String> labelStrings_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#locale">QValue3DAxisFormatter::locale()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QLocale locale(){
        return locale_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QLocale locale_native_constfct(long __this__nativeId);
    
    /**
     * <p>Overloaded function for {@link #markDirty(boolean)}
     *  with <code>labelsChange = false</code>.</p>
     */
    @io.qt.QtUninvokable
    protected final void markDirty() {
        markDirty((boolean)false);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#markDirty">QValue3DAxisFormatter::markDirty(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void markDirty(boolean labelsChange){
        markDirty_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), labelsChange);
    }
    
    @io.qt.QtUninvokable
    private native void markDirty_native_bool(long __this__nativeId, boolean labelsChange);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#setAllowNegatives">QValue3DAxisFormatter::setAllowNegatives(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setAllowNegatives(boolean allow){
        setAllowNegatives_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), allow);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowNegatives_native_bool(long __this__nativeId, boolean allow);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#setAllowZero">QValue3DAxisFormatter::setAllowZero(bool)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setAllowZero(boolean allow){
        setAllowZero_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), allow);
    }
    
    @io.qt.QtUninvokable
    private native void setAllowZero_native_bool(long __this__nativeId, boolean allow);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#setLocale">QValue3DAxisFormatter::setLocale(QLocale)</a></p>
     */
    @io.qt.QtUninvokable
    protected final void setLocale(io.qt.core.QLocale locale){
        setLocale_native_cref_QLocale(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(locale));
    }
    
    @io.qt.QtUninvokable
    private native void setLocale_native_cref_QLocale(long __this__nativeId, long locale);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#subGridPositions">QValue3DAxisFormatter::subGridPositions()const</a></p>
     */
    @io.qt.QtUninvokable
    protected final io.qt.core.QList<java.lang.Float> subGridPositions(){
        return subGridPositions_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QList<java.lang.Float> subGridPositions_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#createNewInstance">QValue3DAxisFormatter::createNewInstance()const</a></p>
     */
    @io.qt.QtUninvokable
    protected io.qt.datavis.QValue3DAxisFormatter createNewInstance(){
        return createNewInstance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.datavis.QValue3DAxisFormatter createNewInstance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#populateCopy">QValue3DAxisFormatter::populateCopy(QValue3DAxisFormatter&amp;)const</a></p>
     */
    @io.qt.QtUninvokable
    protected void populateCopy(io.qt.datavis.QValue3DAxisFormatter copy){
        populateCopy_native_ref_QValue3DAxisFormatter_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(copy));
    }
    
    @io.qt.QtUninvokable
    private native void populateCopy_native_ref_QValue3DAxisFormatter_constfct(long __this__nativeId, long copy);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#positionAt">QValue3DAxisFormatter::positionAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float positionAt(float value){
        return positionAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @io.qt.QtUninvokable
    private native float positionAt_native_float_constfct(long __this__nativeId, float value);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#recalculate">QValue3DAxisFormatter::recalculate()</a></p>
     */
    @io.qt.QtUninvokable
    protected void recalculate(){
        recalculate_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void recalculate_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#stringForValue">QValue3DAxisFormatter::stringForValue(qreal,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    protected java.lang.String stringForValue(double value, java.lang.String format){
        return stringForValue_native_qtjambireal_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), value, format);
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String stringForValue_native_qtjambireal_cref_QString_constfct(long __this__nativeId, double value, java.lang.String format);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qvalue3daxisformatter.html#valueAt">QValue3DAxisFormatter::valueAt(float)const</a></p>
     */
    @io.qt.QtUninvokable
    protected float valueAt(float position){
        return valueAt_native_float_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), position);
    }
    
    @io.qt.QtUninvokable
    private native float valueAt_native_float_constfct(long __this__nativeId, float position);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QValue3DAxisFormatter(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QValue3DAxisFormatter(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QValue3DAxisFormatter instance, QDeclarativeConstructor constructor);
    
}
